@@ -2,11 +2,12 @@
 # CUBE_DIR should refer to the directory in which Cube is placed.
 #CUBE_DIR=~/cube
 #CUBE_DIR=/usr/local/cube
-CUBE_DIR=./
+#CUBE_DIR=./
+CUBE_DIR=$(dirname $(readlink -f "${0}"))
 
 # CUBE_OPTIONS contains any command line options you would like to start Cube with.
 #CUBE_OPTIONS="-f"
-CUBE_OPTIONS="--home=${HOME}/.assaultcube_v1.0 --init"
+CUBE_OPTIONS="--home=${HOME}/.assaultcube_v1.1 --init"
 
 # SYSTEM_NAME should be set to the name of your operating system.
 #SYSTEM_NAME=Linux
@@ -50,7 +51,7 @@ fi
 if [ -x ${CUBE_DIR}/bin_unix/${SYSTEM_NAME}${MACHINE_NAME}client ]
 then
   cd ${CUBE_DIR}
-  exec ${CUBE_DIR}/bin_unix/${SYSTEM_NAME}${MACHINE_NAME}client ${CUBE_OPTIONS} "$@"
+  exec ${CUBE_DIR}/bin_unix/${SYSTEM_NAME}${MACHINE_NAME}client ${CUBE_OPTIONS} "$@" 
 else
   echo "Your platform does not have a pre-compiled Cube client."
   echo "Please follow the following steps to build a native client:"
